"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RedisHealthIndicator = void 0;
const tslib_1 = require("tslib");
const common_1 = require("@nestjs/common");
const terminus_1 = require("@nestjs/terminus");
const ioredis_1 = (0, tslib_1.__importDefault)(require("ioredis"));
const redis_errors_1 = require("redis-errors");
const messages_1 = require("../../messages");
let RedisHealthIndicator = class RedisHealthIndicator extends terminus_1.HealthIndicator {
    /**
     * Checks a redis/cluster connection.
     *
     * @param key - The key which will be used for the result object
     * @param options - The options for check
     *
     * @example
     * ```
     * import IORedis from 'ioredis';
     *
     * const client = new IORedis({ host: '127.0.0.1', port: 6380 });
     * indicator.checkHealth('redis', { client });
     * ```
     *
     * @example
     * ```
     * import IORedis from 'ioredis';
     *
     * const client = new IORedis.Cluster([{ host: '127.0.0.1', port: 16380 }]);
     * indicator.checkHealth('cluster', { client });
     * ```
     */
    async checkHealth(key, options) {
        let isHealthy = false;
        try {
            if (!options.client)
                throw new redis_errors_1.RedisError(messages_1.CLIENT_NOT_FOUND_FOR_HEALTH);
            // * is redis
            if (options.client instanceof ioredis_1.default)
                await options.client.ping();
            // * is cluster
            else {
                // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
                const clusterInfo = await options.client.cluster('info');
                if (clusterInfo && typeof clusterInfo === 'string') {
                    if (!clusterInfo.includes('cluster_state:ok'))
                        throw new redis_errors_1.RedisError(messages_1.FAILED_CLUSTER_STATE);
                }
                else
                    throw new redis_errors_1.RedisError(messages_1.CANNOT_BE_READ);
            }
            isHealthy = true;
        }
        catch (error) {
            if (error instanceof Error) {
                throw new terminus_1.HealthCheckError(error.message, this.getStatus(key, isHealthy, { message: error.message }));
            }
        }
        return this.getStatus(key, isHealthy);
    }
};
RedisHealthIndicator = (0, tslib_1.__decorate)([
    (0, common_1.Injectable)()
], RedisHealthIndicator);
exports.RedisHealthIndicator = RedisHealthIndicator;
